@@ -28,7 +28,7 @@ def fixtures_folder() -> Path:
 
 
 @pytest.fixture
-def config_manager(tmp_path):
+def config_manager(tmp_path) -> ConfigurationManager:
     return ConfigurationManager(config_root_folder=tmp_path)
 
 
